pub fn parse_fasta(path: &str, seq: &SeqArgs) -> Result<(), Error>Expand description
Parses FASTA file and transforms the sequences according to the arguments.
Outputs the results to std::io::stdout() in FASTA/Q format.
Arguments
Check the arguments by --help
Errors
Return an error if the operation cannot be completed.