parse_fastq

Function parse_fastq 

pub fn parse_fastq(path: &str, seq: &SeqArgs) -> Result<(), Error>
Parses FASTQ file and transforms the sequences according to the arguments. Outputs the results to std::io::stdout() in FASTA/Q format.

Arguments

Check the arguments by --help

Errors

Return an error if the operation cannot be completed.