pub struct SampleArgs {
pub in_fq: Option<String>,
pub in_fa: Option<String>,
pub random_seed: Option<usize>,
pub sample_fraction: Option<f64>,
}Fields
in_fq: Option<String>Input fastq path
in_fa: Option<String>Input fasta path
random_seed: Option<usize>Set the seed for the random number generator. This value ensures reproducibility of the sampling process. (This option takes effect only when used in conjunction with –sample-fraction / -f.) [default: 4]
sample_fraction: Option<f64>Specify the fraction of the total dataset to sample. The value is a FLOAT between 0 and 1. For example, a value of 0.1 will sample 10% of the data.