Struct SeqArgs

pub struct SeqArgs {
Show 21 fields pub in_fq: Option<String>, pub in_fa: Option<String>, pub mini_seq_length: Option<usize>, pub drop_ambigous_seq: bool, pub output_odd: bool, pub output_even: bool, pub reverse_complement: bool, pub both_complement: bool, pub output_fasta: bool, pub trim_header: bool, pub line_len: Option<usize>, pub ascii_bases: Option<u8>, pub output_qual_33: bool, pub q_low: Option<u8>, pub q_high: Option<u8>, pub fake_fastq_quality: Option<char>, pub uppercases: bool, pub lowercases_to_char: bool, pub mask_char: Option<char>, pub mask_regions: Option<String>, pub mask_complement_region: bool,
}

Fields

in_fq: Option<String>

Input fastq path

in_fa: Option<String>

Input fasta path

mini_seq_length: Option<usize>

Remove sequences shorter than MINI_SEQ_LENGTH. [default: 0]

drop_ambigous_seq: bool

drop sequences containing ambiguous bases ‘N’

output_odd: bool

Output only the reads from odd-numbered (2n-1) records

output_even: bool

Output only the reads from even-numbered (2n) records

reverse_complement: bool

reverse complement

both_complement: bool

output both forward and reverse complement

output_fasta: bool

force output format to FASTA (discard quality)

trim_header: bool

drop comments at the header lines (only keep the first word before first space)

line_len: Option<usize>

Number of characters per line for sequences and their corresponding quality values [default: all on a single line]

ascii_bases: Option<u8>

The quality scores are represented as chars with ASCII values equal to the score plus a base offset ASCII_BASES [default: 33]

output_qual_33: bool

Output the quality score to an offset of 33 (Effective only when –ascii-bases is not 33)

q_low: Option<u8>

Mask bases with a quality score lower than Q_LOW [default: 0]

q_high: Option<u8>

Mask bases with a quality score higher than Q_HIGH [default: 255]

fake_fastq_quality: Option<char>

Generate fake quality values using the specified CHAR.

uppercases: bool

Converts all bases in the sequences to uppercase. When used in conjunction with other masking options (e.g., –q-low, –q-high, –mask-regions, –mask-char, etc.), the program first converts the sequences to uppercase and then applies the other masking operations.

lowercases_to_char: bool

Convert all lowercases to –mark-char

mask_char: Option<char>

Mask bases by converting them to MASK_CHAR [default: convert to lowercase]

mask_regions: Option<String>

Mask bases that overlap with the regions specified in the BED (0-based) file [default: null]

mask_complement_region: bool

Mask bases that do NOT overlap with the region specified in the BED (effective with –mask-regions / -M)