pub fn subsample_fastx(
fx_path: &str,
sparas: &SampleArgs,
is_fasta: bool,
) -> Result<(), Error>Expand description
Parses FASTQ/A file and sampling according to the seed and fraction.
Outputs the results to std::io::stdout().
Arguments
Check the arguments by --help
Errors
Return an error if the operation cannot be completed.